#ifndef _KVI_STRSUB_H_INCLUDED_
#define _KVI_STRSUB_H_INCLUDED_

// =============================================================================
//
//      --- kvi_strsub.h ---
//
//   This file is part of the KVIrc IRC client distribution
//
//   This program is FREE software. You can redistribute it and/or
//   modify it under the terms of the GNU General Public License
//   as published by the Free Software Foundation; either version 2
//   of the License, or (at your opinion) any later version.
//
//   This program is distributed in the HOPE that it will be USEFUL,
//   but WITHOUT ANY WARRANTY; without even the implied warranty of
//   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
//   See the GNU General Public License for more details.
//
//   You should have received a copy of the GNU General Public License
//   along with this program. If not, write to the Free Software Foundation,
//   Inc, 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
//
// =============================================================================

#include <qptrlist.h>

#include "kvi_string.h"

class KviConfig;

typedef struct
{
	KviStr szOriginal;
	KviStr szSubstitute;
} KviStrSubItem;

class KviStrSub
{
public:
	KviStrSub();
	~KviStrSub();

	bool load(KviConfig *cfg);
	bool save(KviConfig *cfg);

	QPtrList<KviStrSubItem> *m_pList;
};

#endif // _KVI_STRSUB_H_INCLUDED_
